==> kile-1.6.2.tar.bz2: kile-1.6.2/kile/metapostview.cpp <==
/***************************************************************************
                          metapostview.cpp  -  description
                             -------------------
    begin                : mar avr 8 2003
    copyright            : (C) 2003 by Pascal Brachet
    email                : 
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "metapostview.h"

metapostview::metapostview(QWidget *parent, const char *name):QListBox(parent, name)
{
insertItem("beginfig();");
insertItem("endfig;");
insertItem("extra_beginfig()");
insertItem("extra_endfig");
insertItem("begingraph()");
insertItem("endgraph");
insertItem("begingroup");
insertItem("endgroup");
insertItem("for  upto");
insertItem("forever:");
insertItem("forsuffixes :");
insertItem("endfor");
insertItem("if :");
insertItem("else :");
insertItem("fi");
insertItem("----------");
insertItem("abs");
insertItem("addto also");
insertItem("addto contour");
insertItem("addto doublepath");
insertItem("ahangle");
insertItem("ahlength");
insertItem("and");
insertItem("angle");
insertItem("arclength");
insertItem("arctime of");
insertItem("augment.");
insertItem("auto.");
insertItem("Autoform");
insertItem("autogrid()");
insertItem("background");
insertItem("bbox");
insertItem("bboxmargin");
insertItem("beveled");
insertItem("black");
insertItem("blue");
insertItem("bluepart");
insertItem("boolean");
insertItem("bot");
insertItem("boxit");
insertItem("boxjoin()");
insertItem("bp");
insertItem("bpath");
insertItem("btex  etex");
insertItem("buildcycle()");
insertItem("butt");
insertItem("ceiling");
insertItem("char");
insertItem("charcode");
insertItem("circleit");
insertItem("circmargin");
insertItem("clip");
insertItem("color");
insertItem("controls");
insertItem("cosd");
insertItem("curl");
insertItem("currentpen");
insertItem("currentpicture");
insertItem("cutafter");
insertItem("cutbefore");
insertItem("cutdraw");
insertItem("cycle");
insertItem("dashed");
insertItem("dashpattern");
insertItem("day");
insertItem("dd");
insertItem("decimal");
insertItem("decr");
insertItem("defaultdx:=");
insertItem("defaultdy:=");
insertItem("defaultfont:=");
insertItem("defaultpen:=");
insertItem("defaultscale:=");
insertItem("def  enddef");
insertItem("direction   of");
insertItem("directionpoint  of");
insertItem("directiontime  of");
insertItem("ditto");
insertItem("div");
insertItem("dotlabel.");
insertItem("dotlabels.");
insertItem("dotprod");
insertItem("down");
insertItem("downto");
insertItem("draw");
insertItem("draw_mark()");
insertItem("draw_marked()");
insertItem("drawarrow");
insertItem("drawblarrow");
insertItem("drawboxed()");
insertItem("drawboxes()");
insertItem("drawoptions()");
insertItem("drawshadowed()");
insertItem("drawunboxed()");
insertItem("epsilon");
insertItem("evenly");
insertItem("exitif");
insertItem("exitunless");
insertItem("expr");
insertItem("Fe_base");
insertItem("Fe_plus");
insertItem("fill");
insertItem("filldraw");
insertItem("fixpos()");
insertItem("fixsize()");
insertItem("floor");
insertItem("fontsize");
insertItem("format()");
insertItem("frame.");
insertItem("fullcircle");
insertItem("gdata()");
insertItem("gdotlabel.");
insertItem("gdraw");
insertItem("gdrawarrow");
insertItem("gdrawdblarrow");
insertItem("getmid");
insertItem("gfill");
insertItem("glabel.");
insertItem("Gmarks");
insertItem("Gminlog");
insertItem("Gpaths");
insertItem("green");
insertItem("greenpart");
insertItem("grid.");
insertItem("halfcircle");
insertItem("hex");
insertItem("hide()");
insertItem("identity");
insertItem("image()");
insertItem("in");
insertItem("incr()");
insertItem("infinity");
insertItem("infont");
insertItem("init_numbers()");
insertItem("input");
insertItem("interim");
insertItem("intersectionpoint");
insertItem("intersectiontimes");
insertItem("inverse");
insertItem("itick.");
insertItem("joinup()");
insertItem("known");
insertItem("label.");
insertItem("labeloffset");
insertItem("labels.");
insertItem("left");
insertItem("length");
insertItem("let");
insertItem("lft");
insertItem("linear");
insertItem("linecap:=");
insertItem("linejoin:=");
insertItem("llcorner");
insertItem("llft");
insertItem("log");
insertItem("loggingall");
insertItem("lrcorner");
insertItem("lrt");
insertItem("makepath");
insertItem("makepen");
insertItem("mark_angle()");
insertItem("mark_rt_angle()");
insertItem("max");
insertItem("mexp");
insertItem("mfplain");
insertItem("middlepoint()");
insertItem("midpoint()");
insertItem("min");
insertItem("mitered");
insertItem("miterlimit:=");
insertItem("Mlog");
insertItem("mlog");
insertItem("mm");
insertItem("mod");
insertItem("month");
insertItem("mp");
insertItem("mpxbreak");
insertItem("Mreadpath()");
insertItem("Mten");
insertItem("newinternal");
insertItem("normaldeviate");
insertItem("not");
insertItem("nullpicture");
insertItem("numeric");
insertItem("oct");
insertItem("odd");
insertItem("or");
insertItem("origin");
insertItem("otick.");
insertItem("OUT");
insertItem("pair");
insertItem("path");
insertItem("pausing");
insertItem("pc");
insertItem("pen");
insertItem("pencircle");
insertItem("penoffset");
insertItem("pensquare");
insertItem("pic");
insertItem("pickup");
insertItem("picture");
insertItem("plot");
insertItem("point  of");
insertItem("postcontrol");
insertItem("precontrol");
insertItem("primarydef  enddef");
insertItem("pt");
insertItem("quartecircle");
insertItem("readfrom");
insertItem("red");
insertItem("redpart");
insertItem("reflectedabout()");
insertItem("reverse");
insertItem("right");
insertItem("rotated");
insertItem("rotatedaround()");
insertItem("round");
insertItem("rounded");
insertItem("rt");
insertItem("Sabs");
insertItem("Sadd");
insertItem("sarith");
insertItem("save");
insertItem("scaled");
insertItem("Scvnum");
insertItem("Sdiv");
insertItem("secondarydef  enddef");
insertItem("self");
insertItem("setbounds  to");
insertItem("setcoords()");
insertItem("setrange()");
insertItem("shifted");
insertItem("shipout");
insertItem("show");
insertItem("showdependencies");
insertItem("showstopping");
insertItem("showtoken");
insertItem("showvariable");
insertItem("sind");
insertItem("slanted");
insertItem("Sleq");
insertItem("Smul");
insertItem("Sneq");
insertItem("special");
insertItem("sqrt");
insertItem("squared");
insertItem("Ssub");
insertItem("step");
insertItem("str");
insertItem("string");
insertItem("stroked");
insertItem("subpath");
insertItem("substring");
insertItem("tertiarydef  enddef");
insertItem("text");
insertItem("thelabel.");
insertItem("time");
insertItem("top");
insertItem("tracingall");
insertItem("tracingcapsules");
insertItem("tracingchoices");
insertItem("tracingcommands");
insertItem("tracingequations");
insertItem("tracinglostchars");
insertItem("tracingmacros");
insertItem("tracingnone");
insertItem("tracingonline");
insertItem("tracingoutput");
insertItem("tracingrestores");
insertItem("tracingspecs");
insertItem("tracingstats");
insertItem("tracingtitles");
insertItem("transform");
insertItem("transformed");
insertItem("true");
insertItem("truecorners:=");
insertItem("ulcorner");
insertItem("ulft");
insertItem("undraw");
insertItem("unfill");
insertItem("unfilldraw");
insertItem("uniformdeviate");
insertItem("unitsquare");
insertItem("unitvector");
insertItem("unknown");
insertItem("until");
insertItem("up");
insertItem("urcorner");
insertItem("urt");
insertItem("vardef  enddef");
insertItem("whatever[]");
insertItem("white");
insertItem("withcolor");
insertItem("withdots");
insertItem("withpen");
insertItem("write  to");
insertItem("xpart");
insertItem("xscaled");
insertItem("xxpart");
insertItem("xypart");
insertItem("year");
insertItem("yscaled");
insertItem("yxpart");
insertItem("yypart");
insertItem("zscaled");
}
metapostview::~metapostview()
{
}




#include "metapostview.moc"

==> kile-1.7.1.tar.bz2: kile-1.7.1/kile/metapostview.cpp <==
/***************************************************************************
                          metapostview.cpp  -  description
                             -------------------
    begin                : mar avr 8 2003
    copyright            : (C) 2003 - 2003 by Pascal Brachet, 2003 Jeroen Wijnhout
    email                : Jeroen.Wijnhout@kdemail.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "metapostview.h"

metapostview::metapostview(QWidget *parent, const char *name):QListBox(parent, name)
{
insertItem("beginfig();");
insertItem("endfig;");
insertItem("extra_beginfig()");
insertItem("extra_endfig");
insertItem("begingraph()");
insertItem("endgraph");
insertItem("begingroup");
insertItem("endgroup");
insertItem("for  upto");
insertItem("forever:");
insertItem("forsuffixes :");
insertItem("endfor");
insertItem("if :");
insertItem("else :");
insertItem("fi");
insertItem("----------");
insertItem("abs");
insertItem("addto also");
insertItem("addto contour");
insertItem("addto doublepath");
insertItem("ahangle");
insertItem("ahlength");
insertItem("and");
insertItem("angle");
insertItem("arclength");
insertItem("arctime of");
insertItem("augment.");
insertItem("auto.");
insertItem("Autoform");
insertItem("autogrid()");
insertItem("background");
insertItem("bbox");
insertItem("bboxmargin");
insertItem("beveled");
insertItem("black");
insertItem("blue");
insertItem("bluepart");
insertItem("boolean");
insertItem("bot");
insertItem("boxit");
insertItem("boxjoin()");
insertItem("bp");
insertItem("bpath");
insertItem("btex  etex");
insertItem("buildcycle()");
insertItem("butt");
insertItem("ceiling");
insertItem("char");
insertItem("charcode");
insertItem("circleit");
insertItem("circmargin");
insertItem("clip");
insertItem("color");
insertItem("controls");
insertItem("cosd");
insertItem("curl");
insertItem("currentpen");
insertItem("currentpicture");
insertItem("cutafter");
insertItem("cutbefore");
insertItem("cutdraw");
insertItem("cycle");
insertItem("dashed");
insertItem("dashpattern");
insertItem("day");
insertItem("dd");
insertItem("decimal");
insertItem("decr");
insertItem("defaultdx:=");
insertItem("defaultdy:=");
insertItem("defaultfont:=");
insertItem("defaultpen:=");
insertItem("defaultscale:=");
insertItem("def  enddef");
insertItem("direction   of");
insertItem("directionpoint  of");
insertItem("directiontime  of");
insertItem("ditto");
insertItem("div");
insertItem("dotlabel.");
insertItem("dotlabels.");
insertItem("dotprod");
insertItem("down");
insertItem("downto");
insertItem("draw");
insertItem("draw_mark()");
insertItem("draw_marked()");
insertItem("drawarrow");
insertItem("drawblarrow");
insertItem("drawboxed()");
insertItem("drawboxes()");
insertItem("drawoptions()");
insertItem("drawshadowed()");
insertItem("drawunboxed()");
insertItem("epsilon");
insertItem("evenly");
insertItem("exitif");
insertItem("exitunless");
insertItem("expr");
insertItem("Fe_base");
insertItem("Fe_plus");
insertItem("fill");
insertItem("filldraw");
insertItem("fixpos()");
insertItem("fixsize()");
insertItem("floor");
insertItem("fontsize");
insertItem("format()");
insertItem("frame.");
insertItem("fullcircle");
insertItem("gdata()");
insertItem("gdotlabel.");
insertItem("gdraw");
insertItem("gdrawarrow");
insertItem("gdrawdblarrow");
insertItem("getmid");
insertItem("gfill");
insertItem("glabel.");
insertItem("Gmarks");
insertItem("Gminlog");
insertItem("Gpaths");
insertItem("green");
insertItem("greenpart");
insertItem("grid.");
insertItem("halfcircle");
insertItem("hex");
insertItem("hide()");
insertItem("identity");
insertItem("image()");
insertItem("in");
insertItem("incr()");
insertItem("infinity");
insertItem("infont");
insertItem("init_numbers()");
insertItem("input");
insertItem("interim");
insertItem("intersectionpoint");
insertItem("intersectiontimes");
insertItem("inverse");
insertItem("itick.");
insertItem("joinup()");
insertItem("known");
insertItem("label.");
insertItem("labeloffset");
insertItem("labels.");
insertItem("left");
insertItem("length");
insertItem("let");
insertItem("lft");
insertItem("linear");
insertItem("linecap:=");
insertItem("linejoin:=");
insertItem("llcorner");
insertItem("llft");
insertItem("log");
insertItem("loggingall");
insertItem("lrcorner");
insertItem("lrt");
insertItem("makepath");
insertItem("makepen");
insertItem("mark_angle()");
insertItem("mark_rt_angle()");
insertItem("max");
insertItem("mexp");
insertItem("mfplain");
insertItem("middlepoint()");
insertItem("midpoint()");
insertItem("min");
insertItem("mitered");
insertItem("miterlimit:=");
insertItem("Mlog");
insertItem("mlog");
insertItem("mm");
insertItem("mod");
insertItem("month");
insertItem("mp");
insertItem("mpxbreak");
insertItem("Mreadpath()");
insertItem("Mten");
insertItem("newinternal");
insertItem("normaldeviate");
insertItem("not");
insertItem("nullpicture");
insertItem("numeric");
insertItem("oct");
insertItem("odd");
insertItem("or");
insertItem("origin");
insertItem("otick.");
insertItem("OUT");
insertItem("pair");
insertItem("path");
insertItem("pausing");
insertItem("pc");
insertItem("pen");
insertItem("pencircle");
insertItem("penoffset");
insertItem("pensquare");
insertItem("pic");
insertItem("pickup");
insertItem("picture");
insertItem("plot");
insertItem("point  of");
insertItem("postcontrol");
insertItem("precontrol");
insertItem("primarydef  enddef");
insertItem("pt");
insertItem("quartecircle");
insertItem("readfrom");
insertItem("red");
insertItem("redpart");
insertItem("reflectedabout()");
insertItem("reverse");
insertItem("right");
insertItem("rotated");
insertItem("rotatedaround()");
insertItem("round");
insertItem("rounded");
insertItem("rt");
insertItem("Sabs");
insertItem("Sadd");
insertItem("sarith");
insertItem("save");
insertItem("scaled");
insertItem("Scvnum");
insertItem("Sdiv");
insertItem("secondarydef  enddef");
insertItem("self");
insertItem("setbounds  to");
insertItem("setcoords()");
insertItem("setrange()");
insertItem("shifted");
insertItem("shipout");
insertItem("show");
insertItem("showdependencies");
insertItem("showstopping");
insertItem("showtoken");
insertItem("showvariable");
insertItem("sind");
insertItem("slanted");
insertItem("Sleq");
insertItem("Smul");
insertItem("Sneq");
insertItem("special");
insertItem("sqrt");
insertItem("squared");
insertItem("Ssub");
insertItem("step");
insertItem("str");
insertItem("string");
insertItem("stroked");
insertItem("subpath");
insertItem("substring");
insertItem("tertiarydef  enddef");
insertItem("text");
insertItem("thelabel.");
insertItem("time");
insertItem("top");
insertItem("tracingall");
insertItem("tracingcapsules");
insertItem("tracingchoices");
insertItem("tracingcommands");
insertItem("tracingequations");
insertItem("tracinglostchars");
insertItem("tracingmacros");
insertItem("tracingnone");
insertItem("tracingonline");
insertItem("tracingoutput");
insertItem("tracingrestores");
insertItem("tracingspecs");
insertItem("tracingstats");
insertItem("tracingtitles");
insertItem("transform");
insertItem("transformed");
insertItem("true");
insertItem("truecorners:=");
insertItem("ulcorner");
insertItem("ulft");
insertItem("undraw");
insertItem("unfill");
insertItem("unfilldraw");
insertItem("uniformdeviate");
insertItem("unitsquare");
insertItem("unitvector");
insertItem("unknown");
insertItem("until");
insertItem("up");
insertItem("urcorner");
insertItem("urt");
insertItem("vardef  enddef");
insertItem("whatever[]");
insertItem("white");
insertItem("withcolor");
insertItem("withdots");
insertItem("withpen");
insertItem("write  to");
insertItem("xpart");
insertItem("xscaled");
insertItem("xxpart");
insertItem("xypart");
insertItem("year");
insertItem("yscaled");
insertItem("yxpart");
insertItem("yypart");
insertItem("zscaled");
}
metapostview::~metapostview()
{
}




#include "metapostview.moc"
